==> react-native-vidvocr-1.0.0.tgz: package/ios/Vidvocr.swift <==
import UIKit
import VIDVOCR

@objc(Vidvocr)
class Vidvocr: NSObject, VIDVOCRDelegate {
    
    let dispatchGroup = DispatchGroup()
    var jsonResponse = ""
    var success = false
    var capturedImages = [CapturedImageData]()
    @objc(startOCR:withResolver:withRejecter:)
    func startOCR(_ params: NSDictionary,_ resolve: @escaping RCTPromiseResolveBlock,_ reject: @escaping RCTPromiseRejectBlock) {
        
        let baseURL = params.value(forKey: "base_url") as? String ?? ""
        let accessToken = params.value(forKey: "access_token") as? String ?? ""
        let bundle = params.value(forKey: "bundle_key") as? String ?? ""
        let languageString = params.value(forKey: "language") as? String ?? ""
        let documentVerification  = params.value(forKey: "document_verification") as? Bool ?? false
        let dataValidation  = params.value(forKey: "data_validation") as? Bool ?? false
        let returnDataValidationError  = params.value(forKey: "return_data_validation_error") as? Bool ?? false
        let reviewData  = params.value(forKey: "review_data") as? Bool ?? false
        let captureOnlyMode  = params.value(forKey: "capture_only_mode") as? Bool ?? true
        let headers  = params.value(forKey: "headers") as? [String:String] ?? [:]
        let primaryColor = params.value(forKey: "primary_color") as? String ?? ""
        DispatchQueue.main.async {[weak self] in
            guard let self = self else {return}
            var builder = OCRBuilder()
            builder = builder.setDataValidation(validate: dataValidation)
                .setDocumentVerification(verify: documentVerification)
                .setlLanguage(language: languageString)
                .setBundleKey(bundle)
                .setBaseUrl(baseURL)
                .setAccessToken(accessToken)
                .setReviewData(review: reviewData)
                .setCaptureOnlyMode(captureOnlyMode)
                .setReturnValidationError(returnDataValidationError)
            builder = builder.setPrimaryColor(color: self.hexStringToUIColor(hex: primaryColor))
            builder = builder.setHeaders(headers: headers)
            let keyWindow = UIApplication.shared.windows.filter {$0.isKeyWindow}.first
            guard var topController = keyWindow?.rootViewController else {return}
            while let presentedViewController = topController.presentedViewController {
                topController = presentedViewController
            }
            builder.start(vc: topController, ocrDelegate: self)
        }
        
        self.dispatchGroup.enter()
        dispatchGroup.notify(queue: DispatchQueue.global()){
            if self.success {
                resolve(self.jsonResponse)
            } else {
                resolve(self.jsonResponse)
            }
        }
    }
    
    func onOCRResult(result: VIDVOCRResponse) {
        var dict = NSMutableDictionary()
        switch result {
        case .success(let data):
            dict = VIDVResultToDict(VIDVResult: data, hasResult: true, errorMessage: nil, errorCode: nil, step: nil, state: "SUCCESS")
            success = true
        case .builderError(let code, let message):
            dict = VIDVResultToDict(VIDVResult: nil, hasResult: false, errorMessage: message, errorCode: code, step: nil, state: "ERROR")
            success = true
        case .serviceFailure(let code, let message, let data):
            dict = VIDVResultToDict(VIDVResult: data, hasResult: true, errorMessage: message, errorCode: code, step: nil, state: "FAILURE")
            success = true
        case .userExit(let step, let data):
            dict = VIDVResultToDict(VIDVResult: data, hasResult: true, errorMessage: nil, errorCode: nil, step: step, state: "EXIT")
            success = true
        case .capturedImages(capturedImageData: let capturedImageData):
            capturedImages.append(capturedImageData)
            return
        }
        
        do {
            let jsonData = try JSONSerialization.data(withJSONObject: dict, options: .prettyPrinted)
            let json = String(data: jsonData, encoding: .utf8)
            self.jsonResponse = json ?? ""
            dispatchGroup.leave()
        } catch let error as NSError {
            print("Failed to load: \(error.localizedDescription)")
        }
    }
    
    func convertBase64StringToImage(imageBase64String: String) -> UIImage {
        let imageData = Data(base64Encoded: imageBase64String)
        let image = UIImage(data: imageData!)
        return image!
    }
    
    func VIDVResultToDict(VIDVResult: VIDVOCRResult?, hasResult: Bool, errorMessage: String?, errorCode: Int?, step: String?, state: String) -> NSMutableDictionary {
        
        let dict = NSMutableDictionary()
        let nameValuePairs = NSMutableDictionary()
        let valifyData = NSMutableDictionary()
        
        dict["nameValuePairs"] = nameValuePairs
        dict["state"] = state
        if errorCode != nil {
            nameValuePairs["errorCode"] = errorCode
        }
        if errorMessage != nil {
            nameValuePairs["errorMessage"] = errorMessage
        }
        if step != nil {
            nameValuePairs["step"] = step
        }
        
        if hasResult {
            do {
                let jsonEncoder = JSONEncoder()
                let jsonData = try jsonEncoder.encode(VIDVResult)
                let jsonVIDVResult = String(data: jsonData, encoding: .utf8)
                
                let capturedImagesData = try jsonEncoder.encode(capturedImages)
                let capturedImagesResult = String(data: capturedImagesData, encoding: .utf8)
                
                nameValuePairs["ocrResult"] = jsonVIDVResult
                nameValuePairs["capturedImages"] = capturedImagesResult
            } catch {
                print("Failed to encode VIDV Result: \(error.localizedDescription)")
            }
        }
        
        return dict
    }
    func hexStringToUIColor(hex: String?) -> UIColor {
        guard let hex = hex  else {return hexStringToUIColor(hex: "#62CBC9")}
        var cString: String = hex.trimmingCharacters(in: .whitespacesAndNewlines).uppercased()
        
        if cString.hasPrefix("#") {
            cString.remove(at: cString.startIndex)
        }
        
        if (cString.count) != 6 {
            return UIColor.gray
        }
        
        var rgbValue: UInt64 = 0
        Scanner(string: cString).scanHexInt64(&rgbValue)
        
        return UIColor(
            red: CGFloat((rgbValue & 0xFF0000) >> 16) / 255.0,
            green: CGFloat((rgbValue & 0x00FF00) >> 8) / 255.0,
            blue: CGFloat(rgbValue & 0x0000FF) / 255.0,
            alpha: CGFloat(1.0)
        )
    }
}

==> react-native-vidvocr-1.1.1.tgz: package/ios/Vidvocr.swift <==
import UIKit
import VIDVOCR

@objc(Vidvocr)
class Vidvocr: NSObject, VIDVOCRDelegate {
    
    let dispatchGroup = DispatchGroup()
    var jsonResponse = ""
    var success = false
    var capturedImages = [CapturedImageData]()
    @objc(startOCR:withResolver:withRejecter:)
    func startOCR(_ params: NSDictionary,_ resolve: @escaping RCTPromiseResolveBlock,_ reject: @escaping RCTPromiseRejectBlock) {
        
        let baseURL = params.value(forKey: "base_url") as? String ?? ""
        let accessToken = params.value(forKey: "access_token") as? String ?? ""
        let bundle = params.value(forKey: "bundle_key") as? String ?? ""
        let languageString = params.value(forKey: "language") as? String ?? ""
        let documentVerification  = params.value(forKey: "document_verification") as? Bool ?? false
        let dataValidation  = params.value(forKey: "data_validation") as? Bool ?? false
        let returnDataValidationError  = params.value(forKey: "return_data_validation_error") as? Bool ?? false
        let reviewData  = params.value(forKey: "review_data") as? Bool ?? false
        let captureOnlyMode  = params.value(forKey: "capture_only_mode") as? Bool ?? true
        let headers  = params.value(forKey: "headers") as? [String:String] ?? [:]
        let primaryColor = params.value(forKey: "primary_color") as? String ?? ""
        DispatchQueue.main.async {[weak self] in
            guard let self = self else {return}
            var builder = OCRBuilder()
            builder = builder.setDataValidation(validate: dataValidation)
                .setDocumentVerification(verify: documentVerification)
                .setlLanguage(language: languageString)
                .setBundleKey(bundle)
                .setBaseUrl(baseURL)
                .setAccessToken(accessToken)
                .setReviewData(review: reviewData)
                .setCaptureOnlyMode(captureOnlyMode)
                .setReturnValidationError(returnDataValidationError)
            
            builder = builder.setPrimaryColor(color: self.hexStringToUIColor(hex: primaryColor))
            builder = builder.setHeaders(headers: headers)
            let keyWindow = UIApplication.shared.windows.filter {$0.isKeyWindow}.first
            guard var topController = keyWindow?.rootViewController else {return}
            while let presentedViewController = topController.presentedViewController {
                topController = presentedViewController
            }
            builder.start(vc: topController, ocrDelegate: self)
        }
        
        self.dispatchGroup.enter()
        dispatchGroup.notify(queue: DispatchQueue.global()){
            if self.success {
                resolve(self.jsonResponse)
            } else {
                resolve(self.jsonResponse)
            }
        }
    }
    
    func onOCRResult(result: VIDVOCRResponse) {
        var dict = NSMutableDictionary()
        switch result {
        case .success(let data):
            dict = VIDVResultToDict(VIDVResult: data, hasResult: true, errorMessage: nil, errorCode: nil, step: nil, state: "SUCCESS")
            success = true
        case .builderError(let code, let message):
            dict = VIDVResultToDict(VIDVResult: nil, hasResult: false, errorMessage: message, errorCode: code, step: nil, state: "ERROR")
            success = true
        case .serviceFailure(let code, let message, let data):
            dict = VIDVResultToDict(VIDVResult: data, hasResult: true, errorMessage: message, errorCode: code, step: nil, state: "FAILURE")
            success = true
        case .userExit(let step, let data):
            dict = VIDVResultToDict(VIDVResult: data, hasResult: true, errorMessage: nil, errorCode: nil, step: step, state: "EXIT")
            success = true
        case .capturedImages(capturedImageData: let capturedImageData):
            capturedImages.append(capturedImageData)
            return
            
        }
        
        do {
            let jsonData = try JSONSerialization.data(withJSONObject: dict, options: .prettyPrinted)
            let json = String(data: jsonData, encoding: .utf8)
            self.jsonResponse = json ?? ""
            dispatchGroup.leave()
        } catch let error as NSError {
            print("Failed to load: \(error.localizedDescription)")
        }
    }
    
    func convertBase64StringToImage(imageBase64String: String) -> UIImage {
        let imageData = Data(base64Encoded: imageBase64String)
        let image = UIImage(data: imageData!)
        return image!
    }
    
    func VIDVResultToDict(VIDVResult: VIDVOCRResult?, hasResult: Bool, errorMessage: String?, errorCode: Int?, step: String?, state: String) -> NSMutableDictionary {
        
        let dict = NSMutableDictionary()
        let nameValuePairs = NSMutableDictionary()
        let valifyData = NSMutableDictionary()
        
        dict["nameValuePairs"] = nameValuePairs
        nameValuePairs["state"] = state
        if errorCode != nil {
            nameValuePairs["errorCode"] = errorCode
        }
        if errorMessage != nil {
            nameValuePairs["errorMessage"] = errorMessage
        }
        if step != nil {
            nameValuePairs["step"] = step
        }
        
        if hasResult {
            do {
                let jsonEncoder = JSONEncoder()
                let jsonData = try jsonEncoder.encode(VIDVResult)
                let jsonVIDVResult = try JSONSerialization.jsonObject(with: jsonData, options: []) as? [String : Any]
                
                let capturedImagesData = try jsonEncoder.encode(capturedImages)
                let capturedImagesResult = try JSONSerialization.jsonObject(with: capturedImagesData, options: []) as? [String : Any]
                
                nameValuePairs["ocrResult"] = jsonVIDVResult
                nameValuePairs["capturedImages"] = capturedImagesResult
            } catch {
                print("Failed to encode VIDV Result: \(error.localizedDescription)")
            }
        }
        
        return dict
    }
    func hexStringToUIColor(hex: String?) -> UIColor {
        guard let hex = hex  else {return hexStringToUIColor(hex: "#62CBC9")}
        var cString: String = hex.trimmingCharacters(in: .whitespacesAndNewlines).uppercased()
        
        if cString.hasPrefix("#") {
            cString.remove(at: cString.startIndex)
        }
        
        if (cString.count) != 6 {
            return UIColor.gray
        }
        
        var rgbValue: UInt64 = 0
        Scanner(string: cString).scanHexInt64(&rgbValue)
        
        return UIColor(
            red: CGFloat((rgbValue & 0xFF0000) >> 16) / 255.0,
            green: CGFloat((rgbValue & 0x00FF00) >> 8) / 255.0,
            blue: CGFloat(rgbValue & 0x0000FF) / 255.0,
            alpha: CGFloat(1.0)
        )
    }
}
